pub struct PresignedRequest {
pub backend: PresignedRequestBackend,
pub expiration: DateTime<Utc>,
pub operation: PresignedOperation,
pub path: String,
}Expand description
A presigned request that can be serialized, stored, and executed later. Hides implementation details for different storage backends.
Fields
backend: PresignedRequestBackendThe storage backend this request targets
expiration: DateTime<Utc>When this presigned request expires
operation: PresignedOperationThe operation this request performs
path: StringThe path this request operates on
Implementations
Sourceimpl PresignedRequest
impl PresignedRequest
Sourcepub fn new_http(
url: String,
method: String,
headers: HashMap<String, String>,
operation: PresignedOperation,
path: String,
expiration: DateTime<Utc>,
) -> PresignedRequest
pub fn new_http( url: String, method: String, headers: HashMap<String, String>, operation: PresignedOperation, path: String, expiration: DateTime<Utc>, ) -> PresignedRequest
Create a new HTTP-based presigned request
Sourcepub fn new_local(
file_path: String,
operation: PresignedOperation,
path: String,
expiration: DateTime<Utc>,
) -> PresignedRequest
pub fn new_local( file_path: String, operation: PresignedOperation, path: String, expiration: DateTime<Utc>, ) -> PresignedRequest
Create a new local filesystem presigned request
Sourcepub async fn execute(
&self,
body: Option<Bytes>,
) -> Result<PresignedResponse, AlienError<ErrorData>>
pub async fn execute( &self, body: Option<Bytes>, ) -> Result<PresignedResponse, AlienError<ErrorData>>
Execute this presigned request with optional body data. For PUT operations, body should contain the data to upload. For GET/DELETE operations, body is typically None.
Sourcepub async fn execute_with_client(
&self,
client: &Client,
body: Option<Bytes>,
) -> Result<PresignedResponse, AlienError<ErrorData>>
pub async fn execute_with_client( &self, client: &Client, body: Option<Bytes>, ) -> Result<PresignedResponse, AlienError<ErrorData>>
Execute this presigned request with a caller-owned HTTP client.
Multi-step protocols should use this form so retries and adjacent HTTP operations share one connection pool. Local requests ignore the client.
Sourcepub fn url(&self) -> String
pub fn url(&self) -> String
Get a URL representation of this presigned request. For local storage, returns a local:// URL. For cloud storage, returns the actual presigned URL.
Sourcepub fn is_expired(&self) -> bool
pub fn is_expired(&self) -> bool
Check if this presigned request has expired