Function service implementations
Modules
Structs
- Cloud
RunFunction - GCP Cloud Run function binding implementation
- Container
AppFunction - Azure Container Apps function binding implementation
- Grpc
Function - gRPC-based Function implementation that forwards calls to a remote Function service
- Kubernetes
Function - Kubernetes Function implementation that calls functions via internal Kubernetes Services
- Lambda
Function - AWS Lambda function binding implementation
- Local
Function - Local function binding implementation for development and testing.