pub struct LocalQueue { /* private fields */ }Expand description
Local disk-persisted queue implementation using sled embedded database.
This provides a persistent, thread-safe, disk-based message queue that implements all Queue trait features including send, receive with visibility timeout, and ack. Messages survive process restarts.
Implementations
Sourceimpl LocalQueue
impl LocalQueue
Sourcepub async fn new(data_dir: PathBuf) -> Result<LocalQueue, AlienError<ErrorData>>
pub async fn new(data_dir: PathBuf) -> Result<LocalQueue, AlienError<ErrorData>>
Create a new local queue store with the given data directory.
Sourcepub async fn from_binding(
binding: LocalQueueBinding,
) -> Result<LocalQueue, AlienError<ErrorData>>
pub async fn from_binding( binding: LocalQueueBinding, ) -> Result<LocalQueue, AlienError<ErrorData>>
Create a LocalQueue from a LocalQueueBinding.