AzureManagedIdentityServiceAccount

Struct AzureManagedIdentityServiceAccount 

pub struct AzureManagedIdentityServiceAccount { /* private fields */ }
Azure User-Assigned Managed Identity service account binding implementation

Note: Azure impersonation works differently than AWS/GCP. The managed identity must already be attached to the workload (Container App, VM, etc.) at provisioning time. This binding allows selecting which attached identity to use at runtime by providing its client_id to the Azure Identity SDK.

Implementations