Module worker

Module worker 

Worker service implementations

Modules

aws_lambda
azure_container_app
gcp_cloudrun
grpc
kubernetes
local

Structs

CloudRunWorker
GCP Cloud Run worker binding implementation
ContainerAppWorker
Azure Container Apps worker binding implementation
GrpcWorker
gRPC-based Worker implementation that forwards calls to a remote Worker service
KubernetesWorker
Kubernetes Worker implementation that calls workers via internal Kubernetes Services
LambdaWorker
AWS Lambda worker binding implementation
LocalWorker
Local worker binding implementation for development and testing.