pub struct KubernetesBuild { /* private fields */ }Expand description
Kubernetes implementation of the Build trait.
This implementation creates Kubernetes Jobs to execute build operations with proper sandboxing and security context.
Implementations
Sourceimpl KubernetesBuild
impl KubernetesBuild
Sourcepub async fn new(
binding_name: String,
binding: BuildBinding,
) -> Result<KubernetesBuild, AlienError<ErrorData>>
pub async fn new( binding_name: String, binding: BuildBinding, ) -> Result<KubernetesBuild, AlienError<ErrorData>>
Creates a new Kubernetes build instance from binding parameters.