Module function

Module function 

Function service implementations

Modules

aws_lambda
azure_container_app
gcp_cloudrun
grpc
kubernetes
local

Structs

CloudRunFunction
GCP Cloud Run function binding implementation
ContainerAppFunction
Azure Container Apps function binding implementation
GrpcFunction
gRPC-based Function implementation that forwards calls to a remote Function service
KubernetesFunction
Kubernetes Function implementation that calls functions via internal Kubernetes Services
LambdaFunction
AWS Lambda function binding implementation
LocalFunction
Local function binding implementation for development and testing.