pub struct AzureManagedIdentityServiceAccount { /* private fields */ }Expand description
Azure User-Assigned Managed Identity service account binding implementation
Note: Azure impersonation works differently than AWS/GCP. The managed identity must already be attached to the workload (Container App, VM, etc.) at provisioning time. This binding allows selecting which attached identity to use at runtime by providing its client_id to the Azure Identity SDK.
Implementations
Sourceimpl AzureManagedIdentityServiceAccount
impl AzureManagedIdentityServiceAccount
pub fn new( config: AzureClientConfig, binding: AzureServiceAccountBinding, ) -> AzureManagedIdentityServiceAccount