Worker service implementations
Modules
Structs
- Cloud
RunWorker - GCP Cloud Run worker binding implementation
- Container
AppWorker - Azure Container Apps worker binding implementation
- Grpc
Worker - gRPC-based Worker implementation that forwards calls to a remote Worker service
- Kubernetes
Worker - Kubernetes Worker implementation that calls workers via internal Kubernetes Services
- Lambda
Worker - AWS Lambda worker binding implementation
- Local
Worker - Local worker binding implementation for development and testing.