Module traits

Module traits 

App-facing binding value types (the option/message/result types that flow through storage/KV/queue/vault/container calls).

Structs

KvEntry
A KV entry together with its opaque version.
PutOptions
Options for KV put operations.
Queue
A queue binding scoped to its configured queue name.
QueueMessage
A queue message with payload and receipt handle for acknowledgment
ScanResult
Represents the result of a scan operation.

Enums

MessagePayload
JSON/Text message payload for Queue
PutCondition
A precondition for a KV put operation.

Traits

Container
A trait for container bindings that enable container-to-container communication
Kv
A trait for key-value store bindings that provide minimal, platform-agnostic KV operations. This API is designed to work consistently across DynamoDB, Firestore, Azure Table Storage, and the local provider.
Storage
A storage binding that provides object store capabilities.
Vault
A trait for vault bindings that provide secure secret management.