Module traits

Module traits 

App-facing binding value types (the option/message/result types that flow through storage/KV/queue/vault/container calls).

Structs

PutOptions
Represents options for put operations in KV stores.
Queue
A queue binding scoped to its configured queue name.
QueueMessage
A queue message with payload and receipt handle for acknowledgment
ScanResult
Represents the result of a scan operation.

Enums

MessagePayload
JSON/Text message payload for Queue

Traits

Container
A trait for container bindings that enable container-to-container communication
Kv
A trait for key-value store bindings that provide minimal, platform-agnostic KV operations. This API is designed to work consistently across DynamoDB, Firestore, Redis, and Azure Table Storage.
Storage
A storage binding that provides object store capabilities.
Vault
A trait for vault bindings that provide secure secret management.