App-facing binding value types (the option/message/result types that flow through storage/KV/queue/vault calls).
Structs
- PutOptions
- Represents options for put operations in KV stores.
- Queue
Message - A queue message with payload and receipt handle for acknowledgment
- Scan
Result - Represents the result of a scan operation.
Enums
- Message
Payload - JSON/Text message payload for Queue
Traits
- Kv
- A trait for key-value store bindings that provide minimal, platform-agnostic KV operations. This API is designed to work consistently across DynamoDB, Firestore, Redis, and Azure Table Storage.
- Queue
- A trait for queue bindings providing minimal, portable queue operations.
- Storage
- A storage binding that provides object store capabilities.
- Vault
- A trait for vault bindings that provide secure secret management.